
/**
 * XXX - The style rules in this file are very old and very bad.
 *       They need to be given a similar upgrade as classic-win has had.
 **/
 
/* NEW WIDGET LANDING: <menulist> popup */

/* outer frame */
  menulist 
    {
      -moz-binding		  : url(chrome://global/skin/globalBindings.xml#menulist);
      padding             : 0px;
      margin			  : 3px 4px 3px 4px;
      font-size 		  : 10px;
      font-family		  : geneva, arial;
    }

  .menulist-text-box
    {
   	  margin-top		  : 2px;
   	  margin-right		  : 2px;
    }

  .menulist-spring-left 
  	{
  	  background		  : url(chrome://global/skin/menulist-leftcap.gif) no-repeat;	
	  height			  : 18px;
	  width				  : 8px;
  	}

  .menulist-box-middle
    {
      background		  : url(chrome://global/skin/menulist-middle.gif) repeat-x;
      height			  : 18px;
    }
  
  .menulist-dropmarker-right
    {
      background		  : url(chrome://global/skin/menulist-rightcap.gif) no-repeat;
      height			  : 18px;
      width				  : 22px;
    }

/* Clicked States */

  menulist:hover:active > .menulist-spring-left, menulist[open="true"]> .menulist-spring-left
  	{
  	  background		  : url(chrome://global/skin/menulist-clicked-leftcap.gif) no-repeat;	
  	}

  menulist:hover:active > .menulist-box-middle, menulist[open="true"]> .menulist-box-middle
    {
      background		  : url(chrome://global/skin/menulist-clicked-middle.gif) repeat-x;
    }
  
  menulist:hover:active > .menulist-dropmarker-right, menulist[open="true"] > .menulist-dropmarker-right
    {
      background		  : url(chrome://global/skin/menulist-clicked-rightcap.gif) no-repeat;
    }

/* Disabled States */

  .menulist-spring-left[disabled="true"], menulist:hover:active > .menulist-spring-left[disabled="true"]
  	{
  	  background		  : url(chrome://global/skin/menulist-disabled-leftcap.gif) no-repeat;	
  	}

  .menulist-box-middle[disabled="true"], menulist:hover:active > .menulist-box-middle[disabled="true"]
    {
      background		  : url(chrome://global/skin/menulist-disabled-middle.gif) repeat-x;
    }
  
  .menulist-dropmarker-right[disabled="true"], menulist:hover:active > .menulist-dropmarker-right[disabled="true"]
    {
      background		  : url(chrome://global/skin/menulist-disabled-rightcap.gif) no-repeat;
    }

/** rules for EDITABLE menulists (aka 'comboboxes'). 
 **/

/* outer frame */
  menulist[editable="true"] 
    {
      padding             : 0px;
    }

/* icon display frame */
  menulist[editable="true"] > .menu-icon 
    {
      list-style-image    : url("chrome://communicator/skin/bookmarks/bookmark-item.gif");
      background-color    : white;
      padding             : 1px;
      border-left         : 1px inset #CCCCCC;
      border-top          : 1px inset #CCCCCC;
      border-right        : none;
      border-bottom       : 1px inset #CCCCCC;
    }

/* text display frame */    
  menulist[editable="true"] > .menu-text 
    {
      border-left         : none;
      border-top          : 1px inset #CCCCCC;
      border-right        : 1px inset #CCCCCC;
      border-bottom       : 1px inset #CCCCCC;
      margin              : 0px 2px 0px 0px;
    }

/* drop marker display frame */
  menulist[editable="true"] > .menu-dropmarker 
	{
      border              : 1px outset #CCCCCC;
	}

  menulist[editable="true"][open="true"] > .menu-dropmarker 
    {
      border              : 1px inset #CCCCCC;
    }

/* rules for popups and separators associated with menulists */
  menulist > menupopup 
    {
      border			  : 1px solid #313948;
      min-width           : 0px;
      padding             : 0px;
      background-color	  : #C2D0D0;
    }
    
  menulist > menupopup > .popup-internal-box
    {
      border: 0px;
    }
  
  menulist > menupopup > menuseparator 
    {
      border-top: 1px solid #919FA3;
      border-bottom: 1px solid #E6EFEE;
    }

  menulist > menupopup > menuitem 
    {
      padding             : 0px;
      min-width           : 0px;
      max-width           : none;
      color				  : #000000;
    }

  menulist > menupopup > menuitem[menuactive="true"]
    {
    	background-color  : #465B75;
    	color			  : #FFFFFF;
    }

  menulist > menupopup > menuitem[selected="true"] > .menu-iconic-left
    {
      list-style-image    : url(chrome://global/skin/menu-check.gif);
    }
  
  menulist > menupopup > menuitem[menuactive="true"][selected="true"] > .menu-iconic-left
    {
      list-style-image    : url(chrome://global/skin/menu-check-hover.gif);
    }
  
 menulist:focus
   {
      border              : 3px solid #73869C;
      margin			  : 0px 1px 0px 1px;
      -moz-border-radius  : 10px 9px 11px 10px;
   }
  
