 
/******* ToolBox & ToolBar *******/

toolbar
  {
    background-color      : #394B6E;
    // DON'T DELETE.  Removes disappearance of scrollbars in content pane when window is made smaller.
    // Talk to evaughan@netscape.com for details.
    min-width			        : 1px;      
  }
  
.toolbar-primary-image-middle,
.toolbar-primary-image-left,
.toolbar-primary-image-right 
  {
    border-top: 1px solid #DCEEFF;
  }
  
toolbargrippy 
  { 
    -moz-binding         : url("chrome://global/skin/globalBindings.xml#toolbargrippy");
    background-image     : url("chrome://global/skin/tb-grippy-up-bg.gif");
    width                : 11px;
    margin				       : 0px 0px 0px 0px;
    border-top           : 1px solid #E7EFEF;
    border-right         : 1px solid #313439;
    border-bottom        : 1px solid #212429;
  } 

.toolbargrippy-twisty 
  {
    background           : url("chrome://global/skin/tb-grippy-up.gif") no-repeat bottom;
    width                : 11px;
  }
  
toolbargrippy:hover:active
  {
    background-image     : url("chrome://global/skin/tb-grippy-up-clicked-bg.gif");
  }

toolbargrippy:hover:active > .toolbargrippy-twisty
  {
  	background           : url("chrome://global/skin/tb-grippy-up-clicked.gif") no-repeat bottom;
    width                : 11px;
  }

.collapsed-tray-holder
  {
  	background-color	  : #394B6E;
  	border-bottom		    : 1px solid #11151F;
    border-top			      : 1px solid #B6CADF;
  }

toolbargrippy[tbgrippy-collapsed="true"]
  {
    -moz-binding: url("chrome://global/skin/globalBindings.xml#toolbargrippy");
  	margin				  : 1px 0px 1px 2px;
  }

toolbargrippy[tbgrippy-collapsed="true"]:hover:active
  {
  }

.toolbargrippy-twisty-collapsed 
  {
    background: url("chrome://global/skin/tb-grippy-down-clicked.gif") no-repeat bottom;
    width: 11px;
    max-height: 14px;
  }

toolbar[collapsed="true"] > toolbargrippy 
  {
    width                 : 20px;
  }
  
.toolbar-standard > toolbargrippy
  {
  	background-color      : #003366; 
    background-image      : url("chrome://global/skin/taskbar-tab.gif"); 
    background-repeat     : no-repeat;
  }

.toolbar-standard 
  {
    color                 : white;
    background-color      : #394B6E;
    padding               : 0px;
    margin                : 0px;
    border                : none;
  }

.toolbarseparator-standard
  { 
    width                 : 1px;
    border-left           : 1px solid #9D9D9D;
    border-right          : 1px solid #FFFFFF;
    margin                : 2px 0.2em 2px 0.2em;
  } 

.toolbar-primary 
  {
    -moz-binding		      : url("chrome://global/skin/globalBindings.xml#toolbar-primary");
    padding               : 0px;
    background-color	    : transparent;
    background-image	    : none;
  }
  
.toolbar-primary-image-left
  {
    background            : url("chrome://global/skin/navbar-bg-leftcap.gif") no-repeat;
    width				          : 10px;
    height				        : 46px;
    border-bottom         : 1px solid #6583A2;
  }

.toolbar-primary-image-middle
  {
    background            : url("chrome://global/skin/navbar-bg.gif") repeat-x;
    height			  	      : 46px;
    border-bottom         : 1px solid #6583A2;
  }

.toolbar-primary-image-right
  {
    background            : url("chrome://global/skin/navbar-bg-rightcap.gif") no-repeat;
  	width				          : 21px;
  	height				        : 46px;
    border-bottom         : 1px solid #6583A2;
  }

.toolbary-primary-grippy
  {
  	background-image	  : none;
  	background-color	  : transparent;
  }
