
#navigator-throbber
  {
    -moz-binding          : url("chrome://global/skin/globalBindings.xml#throbber");
    list-style-image      : url("chrome://global/skin/animthrob_single.gif");
    margin                : 2px 1px 6px 8px;
    padding               : 0px;
    cursor                : pointer;
    border                : 0px;
    background-color	  : transparent;
    text-align			  : center;
    -moz-user-focus       : ignore;
    min-width			  : 0px;
  }  

#navigator-throbber[busy="true"]
  {
    list-style-image      : url("chrome://global/skin/animthrob.gif");
  }
  
#navigator-throbber:hover:active
  {
    margin               : 2px 1px 6px 8px;
  }

.throbber-icon
  {
  	margin		: 0px 0px;
  }

.throbber-groove-left
  {
  	background			 : url(chrome://communicator/skin/throbber-groove-left.gif) no-repeat;
  	width				 : 3px;
  	height				 : 38px;
  }  

.throbber-groove-right
  {
  	background			 : url(chrome://communicator/skin/throbber-groove-right.gif) no-repeat;
  	width				 : 3px;
  	height				 : 38px;
  }  

.throbber-groove-top
  {
  	background			 : url(chrome://communicator/skin/throbber-groove-top.gif) no-repeat;
  	height				 : 3px;
  	width				 : 32px;
  }  

.throbber-groove-bottom
  {
  	background			 : url(chrome://communicator/skin/throbber-groove-bottom.gif) no-repeat;
  	height				 : 3px;
  	width				 : 32px;
  }  
