/** Contains style definitions for the navigator application 
 **/

@import url(chrome://communicator/skin/);
@import url(chrome://communicator/skin/bookmarks/bookmarks.css);
@import url(chrome://communicator/skin/sidebar/sidebar.css);

#sidebar-parent 
  {
	  margin-right          : 2px;
  }

/*
 * Rules for 'hiding' portions of the chrome for special
 * kinds of browser windows.
 */
window[chromehidden~="menubar"] .chromeclass-menubar {
	display: none;
}

window[chromehidden~="toolbar"] .chromeclass-toolbar {
        display: none;
}

window[chromehidden~="location"] .chromeclass-location {
        display: none;
}

window[chromehidden~="directories"] .chromeclass-directories {
        display: none;
}

window[chromehidden~="status"] .chromeclass-status {
        display: none;
}

window[chromehidden~="extrachrome"] .chromeclass-extrachrome {
        display: none;
}

/*
 * Images for the main buttons
 */
#back-button 
  {
  	margin-left			  : 0px;
    list-style-image      : url("chrome://navigator/skin/back.gif");
  }

#back-button[disabled="true"],
#back-button[disabled="true"]:hover,
#back-button[disabled="true"]:hover:active,
#back-button[disabled="true"] > .menubutton-dual-stack > .menubutton-dual-button,
#back-button[disabled="true"] > .menubutton-dual-stack > .menubutton-dual-button:hover,
#back-button[disabled="true"] > .menubutton-dual-stack > .menubutton-dual-button:hover:active
  {
    list-style-image      : url("chrome://navigator/skin/back-disabled.gif");
  }

#back-button > .menubutton-dual-stack > .menubutton-dual-button:hover
  {
    list-style-image      : url("chrome://navigator/skin/back-hover.gif");
  }

#back-button > .menubutton-dual-stack > .menubutton-dual-button:hover:active
  {
    list-style-image      : url("chrome://navigator/skin/back-clicked.gif");
  }

#forward-button 
  {
    list-style-image      : url("chrome://navigator/skin/forward.gif");
  }

#forward-button[disabled="true"],
#forward-button[disabled="true"]:hover,
#forward-button[disabled="true"]:hover:active,
#forward-button[disabled="true"] > .menubutton-dual-stack > .menubutton-dual-button,
#forward-button[disabled="true"] > .menubutton-dual-stack > .menubutton-dual-button:hover,
#forward-button[disabled="true"] > .menubutton-dual-stack > .menubutton-dual-button:hover:active
  {
    list-style-image      : url("chrome://navigator/skin/forward-disabled.gif");
  }

#forward-button > .menubutton-dual-stack > .menubutton-dual-button:hover
  {
    list-style-image      : url("chrome://navigator/skin/forward-hover.gif");
  }

#forward-button > .menubutton-dual-stack > .menubutton-dual-button:hover:active
  {
    list-style-image      : url("chrome://navigator/skin/forward-clicked.gif");
  }

#stop-button 
  {
	  list-style-image      : url("chrome://navigator/skin/stop.gif");
  } 

#stop-button[disabled="true"],
#stop-button[disabled="true"]:hover,
#stop-button[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://navigator/skin/stop-disabled.gif");
  } 

#stop-button:hover
  {
    list-style-image      : url("chrome://navigator/skin/stop-hover.gif");
  } 

#stop-button:hover:active
  {
    list-style-image      : url("chrome://navigator/skin/stop-clicked.gif");
  } 

#reload-button 
  {
    list-style-image        : url("chrome://navigator/skin/reload.gif");
  }
  
#reload-button[disabled="true"],
#reload-button[disabled="true"]:hover,
#reload-button[disabled="true"]:hover:active
  {
	 list-style-image      : url("chrome://navigator/skin/reload-disabled.gif");
  }

#reload-button:hover
  {
    list-style-image        : url("chrome://navigator/skin/reload-hover.gif");
  }

#reload-button:hover:active
  {
    list-style-image        : url("chrome://navigator/skin/reload-clicked.gif");
  }

#print-button 
  {
    -moz-binding          : url("chrome://communicator/skin/menubuttonBindings.xml#menubutton-dual-foo");
    list-style-image	  : url("chrome://global/skin/print.gif");
	margin                : 6px 6px 10px 6px;
  }

#print-button[disabled="true"],
#print-button[disabled="true"]:hover,
#print-button[disabled="true"]:hover:active,
#print-button[disabled="true"] > .menubutton-dual-stack > .menubutton-dual-button,
#print-button[disabled="true"] > .menubutton-dual-stack > .menubutton-dual-button:hover,
#print-button[disabled="true"] > .menubutton-dual-stack > .menubutton-dual-button:hover:active
  {
    list-style-image      : url("chrome://global/skin/print-disabled.gif");
  }

#print-button > .menubutton-dual-stack > .menubutton-dual-button:hover
  {
    list-style-image      : url("chrome://global/skin/print-hover.gif");
  }

#print-button > .menubutton-dual-stack > .menubutton-dual-button:hover:active
  {
    list-style-image      : url("chrome://global/skin/print-clicked.gif");
  }

#print-button > .menubutton-dual-stack > .menubutton-dual-dropmarker-box
  {
    margin-left             : 19px;
    margin-top				: 22px;
  }


/* Hides text below the above buttons */
.button-toolbar-1 > .button-internal-box > .button-text-container
  {
  	display					: none;
  }


/*all the urlbar stuff*/

#nav-bar > .toolbar-primary-image-left, #nav-bar > .toolbar-primary-image-middle, #nav-bar > .toolbar-primary-image-right
{
	max-height	: 43px;
}

#nav-bar-inner
  {
  	-moz-binding		  : url("chrome://global/skin/globalBindings.xml#nav-bar-inner");
	margin				  : 6px 0px 9px 6px;
    min-width			  : 0px;
  }

.navbar-inner-groove-image-left                                                 
  {                                                                             
	list-style-image          : url("chrome://navigator/skin/navbar-inner-groove-left.gif");
	width                             : 6px;                                
	height                            : 31px;
  }

/* 3px border on top and bottom of navbar-inner */

.navbar-inner-border-outer
  {
  	border-top			  : 1px solid #A0B3C7;
  	border-bottom		  : 1px solid #7C92AF;
  }

.navbar-inner-border-middle
  {
  	border-top			  : 1px solid #7D91AA;
  	border-bottom		  : 1px solid #4E6179;
  }
 
.navbar-inner-border-inner
  {
  	border-top			  : 1px solid #BBCDE3;
  	border-bottom		  : 1px solid #556D8B;
  }

.navbar-inner-groove-image-right                                                
  {                                                                             
	list-style-image          : url("chrome://navigator/skin/navbar-inner-groove-right.gif");
	width                     : 6px;                                
	height                    : 31px;                               
  }


#urlbar-group
  {
  	-moz-binding		  : url("chrome://global/skin/globalBindings.xml#urlbar-group");
  	margin				  : 3px 8px 4px 2px;
  }

.urlbar-image-left
  {
  	list-style-image          : url("chrome://navigator/skin/urlbar-left.gif");
  	width                     : 3px;
  	height                    : 18px;
  }

.urlbar-border-outer
  {
  	border-top			  : 1px solid #65696D;
  }

.urlbar-border-inner
  {
  	border-top			  : 1px solid #A3A3A3;
  }

.urlbar-image-right                                                             
  {                                                                             
	list-style-image          : url("chrome://navigator/skin/urlbar-right.gif");
	width                             : 4px;                                
	height                            : 18px;                               
  }



#page-proxy-button 
  {
  	margin-left			  : 0px;
  	margin-right		  : 2px;
  	margin-top			  : 0px;
    list-style-image      : url("chrome://communicator/skin/bookmarks/bookmark-item.gif"); 
	cursor                : grab;
  } 


/* #ubhist-keyword-popup does not exist in Mozilla, only in Netscape.  It gets overlayed in with 
 * navExtraOverlay.xul.  Ideally, this styling should only exist in Netscape, but since it is
 * in Mozilla right now, it should not be removed before we ship.  Take this out and put it in
 * commercial after shipping.  (8/24/00) - nbhatla
 */

#ubhist-keyword-popup
  {
    margin                : 3px 4px 8px 3px;
    width                 : 10px; 
    list-style-image      : url("chrome://navigator/skin/ubhist-keyword-popup.gif");
    background-color	  : transparent;
    border				  : 0px;
  } 

#ubhist-keyword-popup > .menubutton-icon-internal-box
  {
  	border				  : 0px;
  }

#ubhist-keyword-popup:hover:active
  {
    margin                : 3px 4px 8px 3px;
    width                 : 10px; 
    list-style-image      : url("chrome://navigator/skin/ubhist-keyword-popup-active.gif"); 
  } 

/*************************************/

#ubhist
  {
    margin                : 1px 1px 3px 0px;
    width                 : 10px; 
    list-style-image      : url("chrome://global/skin/simple-arrow-down.gif"); 
    border                : none;
    padding               : 0px;
  }

#ubhist-popup
  {
    max-width             : none !important;
  }

#action-popup 
  {
    list-style-image      : url("chrome://global/skin/simple-arrow-down.gif"); 
    margin                : 0px; 
    -moz-border-radius    : 4px;
  }

#content-frame 
  {
    min-width             : 0px;
    min-height            : 0px;
  }

#statusbar-icon 
  {
    width                 : 100px;
  }

#statusbar-display
  {
    list-style-image      : url("chrome://communicator/skin/document.gif");
  }
  
#statusbar-display[error="true"]
  {
    list-style-image      : url("chrome://communicator/skin/document-error.gif");
  }  
  
#search-button
  {
    margin-right          : 4px;
  }
  
#home-button
  {
    list-style-image      : url("chrome://communicator/skin/bookmarks/home.gif");
  }
  
.menuitem-iconic
  {
    padding               : 2px;
  }

#navigator-throbber
  {
    -moz-user-focus       : ignore !important;
  }

#PersonalToolbar
  {
  	background-color	  : #394B6E;
    border-bottom       : 1px solid #000000;
  }
